@@ -11,7 +11,8 @@ using namespace cxxmph;
 
 typedef MapTester<mph_map> Tester;
 
-/*
+CXXMPH_CXX_TEST_CASE(empty_find, Tester::empty_find);
+CXXMPH_CXX_TEST_CASE(empty_erase, Tester::empty_erase);
 CXXMPH_CXX_TEST_CASE(small_insert, Tester::small_insert);
 CXXMPH_CXX_TEST_CASE(large_insert, Tester::large_insert);
 CXXMPH_CXX_TEST_CASE(small_search, Tester::small_search);
@@ -21,5 +22,4 @@ CXXMPH_CXX_TEST_CASE(string_search, Tester::string_search);
 CXXMPH_CXX_TEST_CASE(rehash_zero, Tester::rehash_zero);
 CXXMPH_CXX_TEST_CASE(rehash_size, Tester::rehash_size);
 CXXMPH_CXX_TEST_CASE(erase_value, Tester::erase_value);
-*/
 CXXMPH_CXX_TEST_CASE(erase_iterator, Tester::erase_iterator);
