@@ -107,7 +107,7 @@ int main(int argc, char **argv)
 	else source = cmph_io_nlnkfile_adapter(keys_fd, nkeys);
 
 	cmph_uint8 * hashtable = NULL;
-	mphf_fd = fopen(mphf_file, "r");
+	mphf_fd = fopen(mphf_file, "rb");
 	if (mphf_fd == NULL)
 	{
 		fprintf(stderr, "Unable to open input file %s: %s\n", mphf_file, strerror(errno));
